# Copyright (c) Meta Platforms, Inc. and affiliates.

# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

import subprocess
import os

DIVIDING_LINE = "="*150

class Mockbuild():

    @staticmethod
    def mockbuild(pkgs, release):
        """ Mock build all new packages """
        fails = []
        successes = []
        for pkg in pkgs:
            pkg_data = pkgs[pkg]
            if pkg_data["type"] == "new":
                os.chdir(f"{os.getcwd()}/{pkg}")
                print(DIVIDING_LINE)
                print(f"Mockbuild {pkg} for release {release}")
                print(DIVIDING_LINE)
                output = subprocess.run(['fedpkg', '--release', release, "mockbuild"])
                if output.returncode != 0:
                    fails.append(pkg)
                else:
                    successes.append(pkg)
                os.chdir(f"{os.getcwd()}/..")
        if len(successes) + len(fails) == 0:
            print("No new package found for mockbuild.")
            return
        # summary
        print(DIVIDING_LINE)
        print("Summary")
        print(DIVIDING_LINE)
        if len(successes) > 0:
            print("Mockbuild succeeds for the following packages:")
            for pkg in successes:
                print(f"      {pkg}")
        if len(fails) > 0:
            print("Mockbuild fails for the following packages:")
            for pkg in fails:
                print(f"      {pkg}")
