# Copyright (c) Meta Platforms, Inc. and affiliates.

# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

import subprocess

def print_cmd_output(output, prefix=""):
        """ Print cmd output with warning color"""
        out = output.stdout.decode().split("\n")[:-1]
        err = output.stderr.decode().split("\n")[:-1]
        for line in out:
            print(prefix+line)
        for line in err:
            print(prefix+line)

class RequestRepo:

    @staticmethod
    def request_repos(pkgs, compat_pkgs):
        """ Request repos for all compat packages and new packages """
        for pkg in pkgs:
            pkg_data = pkgs[pkg]
            if pkg_data["type"] == "new":
                if pkg_data["bugzilla"] == -1:
                    print(f"Request repo for new package {pkg} without Bugzilla ID")
                else:
                    print(f"Request repo for new package {pkg} without Bugzilla ID {pkg_data['bugzilla']}")
                RequestRepo.request_repo(pkg, pkg_data["bugzilla"])
        for pkg in compat_pkgs:
            print(f"Request repo for compat package {pkg}")
            RequestRepo.request_repo(pkg)

    @staticmethod
    def request_repo(pkg, bugzilla=-1):
        """ Request repo by running 'fedpkg request-repo' """
        if bugzilla == -1:
            bugzilla = ""
        else: 
            bugzilla = str(bugzilla)
        output = subprocess.run(["fedpkg", "request-repo", pkg, bugzilla], capture_output=True)
        print_cmd_output(output, prefix=" "*6)
    
    @staticmethod
    def request_branches(pkgs, compat_pkgs, branch, all_release):
        """ Request repos for all compat packages and new packages """
        for pkg in pkgs:
            pkg_data = pkgs[pkg]
            if pkg_data["type"] == "new":
                RequestRepo.request_branch(pkg, branch, all_release)
        for pkg in compat_pkgs:
            RequestRepo.request_branch(pkg, branch, all_release)

    @staticmethod
    def request_branch(pkg, branch, all_release):
        """ Request replease branch by running 'fedpkg request-branch' """
        if all_release:
            print(f"Request all release branches for {pkg}")
            output = subprocess.run(["fedpkg", "request-branch", pkg, "--all-releases"], capture_output=True)
        else:
            print(f"Request release branch {branch} for {pkg}")
            output = subprocess.run(["fedpkg", "request-branch", pkg, branch], capture_output=True)
        print_cmd_output(output, prefix=" "*6)
    